# 🔧 PlugSnatcher - Development Roadmap

## Project Setup ✅
- [x] Create project roadmap
- [x] Initialize Tauri + React project
- [x] Setup basic project structure
- [x] Create Remote repository (optional)

## Core Infrastructure (In Progress)
- [x] Setup SQLite or JSON storage for plugin data
- [x] Create core data models
- [x] Build server/plugin directory scanner (basic implementation)
- [x] Implement JAR file parser for plugin.yml extraction

## Plugin Discovery (In Progress)
- [x] Create server type detection (Paper, Spigot, etc.)
- [x] Implement plugins folder detection logic
- [x] Design plugin metadata extraction system
- [x] Build plugin hash identification system

## Web Crawler Development (In Progress)
- [x] Create base web crawler architecture
- [x] Implement HangarMC crawler
- [ ] Implement SpigotMC crawler
- [ ] Implement Modrinth crawler
- [ ] Implement GitHub releases crawler
- [ ] Create plugin matching algorithm

## Update Management (Upcoming)
- [ ] Build update detection system
- [ ] Implement changelog extraction
- [ ] Create plugin backup functionality
- [ ] Develop plugin replacement logic
- [ ] Add server restart capabilities (optional)

## UI Development (In Progress)
- [x] Design and implement main dashboard
- [x] Create plugin list view with version indicators
- [x] Build server folder selection interface
- [x] Implement plugin detail view
- [x] Add update notification system
- [ ] Create settings panel
- [x] Implement dark mode

## Security Features (Upcoming)
- [ ] Implement sandboxing for network requests
- [ ] Add SHA256 checksum verification
- [ ] Create download warning system for unverified sources

## Testing & Refinement (Upcoming)
- [ ] Comprehensive testing with various server setups
- [ ] Performance optimization
- [ ] Error handling improvements
- [ ] User acceptance testing

## Documentation (Upcoming)
- [ ] Create user documentation
- [ ] Write developer documentation
- [ ] Create installation guide

## Deployment (Upcoming)
- [ ] Prepare release process
- [ ] Package application for Windows
- [ ] Package application for macOS
- [ ] Package application for Linux
- [ ] Create project website (optional)

## Future Enhancements (v0.2.0+)
- [ ] Plugin conflict checker
- [ ] Minecraft version compatibility checker
- [ ] Server config backup & restore manager
- [ ] Scheduled plugin update checks
- [ ] Rollback system
- [ ] Plugin recommendation system
- [ ] Discord webhook integration